@@ -11,11 +11,12 @@ class Banks(ListoAPI):
         return self.make_request(method="GET", path="/banks/bank_transaction/facets") \
                .json()['facets']['bank_account']
 
-    def upload_bank_files(self, filename, bank=None, account_number=None, currency=None, rfc_id=None):
-        return self.make_request(method="POST", path="banks/upload_bank_files", file=open(filename, 'rb'),
+    def upload_bank_files(self, file_stream, bank=None, account_number=None, currency=None, rfc_id=None):
+        return self.make_request(method="POST", path="banks/upload_bank_files", files=file_stream,
           data= {"bank": bank,"account_number": account_number,"currency": currency,"rfc_id": rfc_id})\
                .json()['status']
     
-    def get_bank_transaction(self, **kwargs):
+    def get_bank_transactions(self, **kwargs):
         return self.make_request(method="GET", path="/banks/bank_transaction", params=kwargs) \
-               .json()['count']['hits']
+               .json()['hits']
+               
